@@ -42,7 +42,7 @@ import (
 
 // The kamelets trait is a platform trait used to inject Kamelets into the integration runtime.
 //
-// +camel-k:trait=kamelets
+// +camel-k:trait=kamelets.
 type kameletsTrait struct {
 	BaseTrait `property:",squash"`
 	// Automatically inject all referenced Kamelets and their default configuration (enabled by default)
@@ -76,7 +76,7 @@ func newKameletsTrait() Trait {
 	}
 }
 
-// IsPlatformTrait overrides base class method
+// IsPlatformTrait overrides base class method.
 func (t *kameletsTrait) IsPlatformTrait() bool {
 	return true
 }
@@ -259,9 +259,11 @@ func (t *kameletsTrait) addKameletAsSource(e *Environment, kamelet *v1alpha1.Kam
 		template := kamelet.Spec.Template
 		if template == nil {
 			// Backward compatibility with Kamelets using flow
-			template = &v1.Template{
-				RawMessage: kamelet.Spec.Flow.RawMessage,
+			var bytes []byte = kamelet.Spec.Flow.RawMessage
+			template = &v1alpha1.Template{
+				RawMessage: make(v1alpha1.RawMessage, len(bytes)),
 			}
+			copy(template.RawMessage, bytes)
 		}
 		flowData, err := dsl.TemplateToYamlDSL(*template, kamelet.Name)
 		if err != nil {
